@@ -126,7 +126,7 @@ def update_logged_request_data(request, related_objects=None, slug=None, extra_d
     input_request_logger = getattr(request, 'input_request_logger', None)
     if input_request_logger:
         if related_objects:
-            input_request_logger.add_related_objects(related_objects)
+            input_request_logger.add_related_objects(*related_objects)
         if slug:
             input_request_logger.set_slug(slug)
         if extra_data:
